@@ -43,11 +43,11 @@ class MessageTestCase(test_base.BaseTestCase):
         message = _message.Message('some %s') % 'message'
         self.assertIsInstance(message, str)
 
-    @mock.patch('locale.getdefaultlocale')
+    @mock.patch('locale.getlocale')
     @mock.patch('gettext.translation')
     def test_create_message_non_english_default_locale(self,
                                                        mock_translation,
-                                                       mock_getdefaultlocale):
+                                                       mock_locale):
         msgid = 'A message in English'
         es_translation = 'A message in Spanish'
 
@@ -55,7 +55,7 @@ class MessageTestCase(test_base.BaseTestCase):
         translations_map = {'es': es_translations}
         translator = fakes.FakeTranslations.translator(translations_map)
         mock_translation.side_effect = translator
-        mock_getdefaultlocale.return_value = ('es',)
+        mock_locale.return_value = ('es',)
 
         message = _message.Message(msgid)
 
@@ -197,7 +197,7 @@ class MessageTestCase(test_base.BaseTestCase):
             results.append(_message.Message(msgid) % param)
 
         for message, result in zip(messages, results):
-            self.assertEqual(type(result), _message.Message)
+            self.assertIsInstance(result, _message.Message)
             self.assertEqual(message, result.translation())
 
             # simulate writing out as string
@@ -388,14 +388,11 @@ class MessageTestCase(test_base.BaseTestCase):
             self.assertEqual(default_translation, msg.translation('es'))
 
             self.assertEqual(1, len(w))
-            # Note(gibi): in python 3.4 str.__repr__ does not put the unicode
-            # marker 'u' in front of the string representations so the test
-            # removes that to have the same result in python 2.7 and 3.4
             self.assertEqual("Failed to insert replacement values into "
                              "translated message A message in Spanish: %s %s "
                              "(Original: 'A message: %s'): "
                              "not enough arguments for format string",
-                             str(w[0].message).replace("u'", "'"))
+                             str(w[0].message))
 
         mock_log.debug.assert_called_with(('Failed to insert replacement '
                                            'values into translated message '
@@ -405,11 +402,11 @@ class MessageTestCase(test_base.BaseTestCase):
                                           mock.ANY)
 
     @mock.patch('gettext.translation')
-    @mock.patch('locale.getdefaultlocale', return_value=('es', ''))
+    @mock.patch('locale.getlocale', return_value=('es', ''))
     @mock.patch('oslo_i18n._message.LOG')
     def test_translate_message_bad_default_translation(self,
                                                        mock_log,
-                                                       mock_local,
+                                                       mock_locale,
                                                        mock_translation):
         message_with_params = 'A message: %s'
         es_translation = 'A message in Spanish: %s %s'
@@ -425,14 +422,11 @@ class MessageTestCase(test_base.BaseTestCase):
             warnings.simplefilter("always")
             msg = msg % param
             self.assertEqual(1, len(w))
-            # Note(gibi): in python 3.4 str.__repr__ does not put the unicode
-            # marker 'u' in front of the string representations so the test
-            # removes that to have the same result in python 2.7 and 3.4
             self.assertEqual("Failed to insert replacement values into "
                              "translated message A message in Spanish: %s %s "
                              "(Original: 'A message: %s'): "
                              "not enough arguments for format string",
-                             str(w[0].message).replace("u'", "'"))
+                             str(w[0].message))
 
         mock_log.debug.assert_called_with(('Failed to insert replacement '
                                            'values into translated message '
@@ -565,11 +559,11 @@ class MessageTestCase(test_base.BaseTestCase):
         self.assertEqual(expected_translation, msg.translation('es'))
         self.assertEqual(default_translation, msg.translation('XX'))
 
-    @mock.patch('locale.getdefaultlocale')
+    @mock.patch('locale.getlocale')
     @mock.patch('gettext.translation')
     def test_translate_message_non_default_locale(self,
                                                   mock_translation,
-                                                  mock_getdefaultlocale):
+                                                  mock_locale):
         message_with_params = 'A message with params: %(param)s'
         es_translation = 'A message with params in Spanish: %(param)s'
         zh_translation = 'A message with params in Chinese: %(param)s'
@@ -591,7 +585,7 @@ class MessageTestCase(test_base.BaseTestCase):
                                                         'zh': zh_translations,
                                                         'fr': fr_translations})
         mock_translation.side_effect = translator
-        mock_getdefaultlocale.return_value = ('es',)
+        mock_locale.return_value = ('es',)
 
         msg = _message.Message(message_with_params)
         msg_param = _message.Message(message_param)
@@ -601,7 +595,7 @@ class MessageTestCase(test_base.BaseTestCase):
         zh_translation = zh_translation % {'param': zh_param_translation}
         fr_translation = fr_translation % {'param': fr_param_translation}
 
-        # Because sys.getdefaultlocale() was Spanish,
+        # Because sys.getlocale() was Spanish,
         # the default translation will be to Spanish
         self.assertEqual(es_translation, msg)
         self.assertEqual(es_translation, msg.translation())
